@@ -128,17 +128,18 @@ datestring(time_t t)
 {
     struct tm mytm;
     Sysutil::get_local_time(&t, &mytm);
-    return Strutil::sprintf("%4d:%02d:%02d %02d:%02d:%02d", mytm.tm_year + 1900,
-                            mytm.tm_mon + 1, mytm.tm_mday, mytm.tm_hour,
-                            mytm.tm_min, mytm.tm_sec);
+    return Strutil::fmt::format("{:4d}:{:02d}:{:02d} {:02d}:{:02d}:{:02d}",
+                                mytm.tm_year + 1900, mytm.tm_mon + 1,
+                                mytm.tm_mday, mytm.tm_hour, mytm.tm_min,
+                                mytm.tm_sec);
 }
 
 
 
 template<class SRCTYPE>
 static void
-interppixel_NDC_clamped(const ImageBuf& buf, float x, float y, float* pixel,
-                        bool envlatlmode)
+interppixel_NDC_clamped(const ImageBuf& buf, float x, float y,
+                        span<float> pixel, bool envlatlmode)
 {
     int fx = buf.spec().full_x;
     int fy = buf.spec().full_y;
@@ -189,7 +190,7 @@ interppixel_NDC_clamped(const ImageBuf& buf, float x, float y, float* pixel,
     }
 
     // Bilinearly interpolate
-    bilerp(p0, p1, p2, p3, xfrac, yfrac, n, pixel);
+    bilerp(p0, p1, p2, p3, xfrac, yfrac, n, pixel.data());
 }
 
 
@@ -210,12 +211,12 @@ resize_block_(ImageBuf& dst, const ImageBuf& src, ROI roi, bool envlatlmode)
            || srcspec.z + srcspec.depth < srcspec.full_z + srcspec.full_depth);
 
     const ImageSpec& dstspec(dst.spec());
-    float* pel    = OIIO_ALLOCA(float, dstspec.nchannels);
-    float xoffset = (float)dstspec.full_x;
-    float yoffset = (float)dstspec.full_y;
-    float xscale  = 1.0f / (float)dstspec.full_width;
-    float yscale  = 1.0f / (float)dstspec.full_height;
-    int nchannels = dst.nchannels();
+    span<float> pel = OIIO_ALLOCA_SPAN(float, dstspec.nchannels);
+    float xoffset   = (float)dstspec.full_x;
+    float yoffset   = (float)dstspec.full_y;
+    float xscale    = 1.0f / (float)dstspec.full_width;
+    float yscale    = 1.0f / (float)dstspec.full_height;
+    int nchannels   = dst.nchannels();
     OIIO_DASSERT(dst.spec().format == TypeFloat);
     ImageBuf::Iterator<float> d(dst, roi);
     for (int y = y0; y < y1; ++y) {
@@ -334,7 +335,7 @@ check_nan_block(const ImageBuf& src, ROI roi, int& found_nonfinite)
 {
     int x0 = roi.xbegin, x1 = roi.xend, y0 = roi.ybegin, y1 = roi.yend;
     const ImageSpec& spec(src.spec());
-    float* pel = OIIO_ALLOCA(float, spec.nchannels);
+    span<float> pel = OIIO_ALLOCA_SPAN(float, spec.nchannels);
     for (int y = y0; y < y1; ++y) {
         for (int x = x0; x < x1; ++x) {
             src.getpixel(x, y, pel);
@@ -384,7 +385,7 @@ lightprobe_to_envlatl(ImageBuf& dst, const ImageBuf& src, bool y_is_up,
         const ImageSpec& dstspec(dst.spec());
         int nchannels = dstspec.nchannels;
 
-        float* pixel = OIIO_ALLOCA(float, nchannels);
+        span<float> pixel = OIIO_ALLOCA_SPAN(float, nchannels);
         float dw = dstspec.width, dh = dstspec.height;
         for (ImageBuf::Iterator<float> d(dst, roi); !d.done(); ++d) {
             Imath::V3f V = latlong_to_dir((d.x() + 0.5f) / dw,
@@ -444,7 +445,7 @@ normal_gradient(const ImageBuf& src, const ImageBuf::Iterator<float>& dstpix,
 {
     // assume a normal defined in the tangent space
     float n[3];
-    src.getpixel(dstpix.x(), dstpix.y(), n, 3);
+    src.getpixel(dstpix.x(), dstpix.y(), make_span(n));
     *h     = -1.0f;
     *dh_ds = -n[0] / n[2];
     *dh_dt = -n[1] / n[2];
@@ -539,9 +540,9 @@ bump_to_bumpslopes(ImageBuf& dst, const ImageBuf& src,
 static void
 fix_latl_edges(ImageBuf& buf)
 {
-    int n        = buf.nchannels();
-    float* left  = OIIO_ALLOCA(float, n);
-    float* right = OIIO_ALLOCA(float, n);
+    int n             = buf.nchannels();
+    span<float> left  = OIIO_ALLOCA_SPAN(float, n);
+    span<float> right = OIIO_ALLOCA_SPAN(float, n);
 
     // Make the whole first and last row be solid, since they are exactly
     // on the pole
@@ -614,7 +615,7 @@ write_mipmap(ImageBufAlgo::MakeTextureMode mode, std::shared_ptr<ImageBuf>& img,
              std::ostream& outstream, double& stat_writetime,
              double& stat_miptime, size_t& peak_mem)
 {
-    using OIIO::pvt::errorfmt;
+    using OIIO::errorfmt;
     using OIIO::Strutil::sync::print;  // Be sure to use synchronized one
     bool envlatlmode       = (mode == ImageBufAlgo::MakeTxEnvLatl);
     bool orig_was_overscan = (img->spec().x || img->spec().y || img->spec().z
@@ -747,8 +748,9 @@ write_mipmap(ImageBufAlgo::MakeTextureMode mode, std::shared_ptr<ImageBuf>& img,
                     outstream << "WARNING: Custom mip level \"" << mipimages[0]
                               << " had the wrong number of channels.\n";
                     std::shared_ptr<ImageBuf> t(new ImageBuf(smallspec));
-                    ImageBufAlgo::channels(*t, *small, outspec.nchannels, NULL,
-                                           NULL, NULL, true);
+                    ImageBufAlgo::channels(*t, *small, outspec.nchannels,
+                                           cspan<int>(), cspan<float>(),
+                                           cspan<std::string>(), true);
                     std::swap(t, small);
                 }
                 smallspec.tile_width  = outspec.tile_width;
@@ -828,7 +830,8 @@ write_mipmap(ImageBufAlgo::MakeTextureMode mode, std::shared_ptr<ImageBuf>& img,
                             errorfmt("{}", sharp->geterror());
                         std::swap(img, sharp);
                     }
-                    ImageBufAlgo::resize(*small, *img, filter);
+                    ImageBufAlgo::resize(*small, *img,
+                                         { make_pv("filterptr", filter) });
                     if (sharpen > 0.0f && !sharpen_first) {
                         std::shared_ptr<ImageBuf> sharp(new ImageBuf);
                         bool uok = ImageBufAlgo::unsharp_mask(*sharp, *small,
@@ -978,7 +981,7 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
                   std::string filename, std::string outputfilename,
                   const ImageSpec& _configspec, std::ostream* outstream_ptr)
 {
-    using OIIO::pvt::errorfmt;
+    using OIIO::errorfmt;
     using OIIO::Strutil::sync::print;  // Be sure to use synchronized one
     OIIO_ASSERT(mode >= 0 && mode < ImageBufAlgo::_MakeTxLast);
     double stat_readtime         = 0;
@@ -1035,8 +1038,9 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
         src.reset(new ImageBuf(*input));
     } else {
         // Image buffer supplied that has pixels -- wrap it
-        src.reset(new ImageBuf(input->name(), input->spec(),
-                               (void*)input->localpixels()));
+        src.reset(new ImageBuf(input->spec(),
+                               make_cspan((std::byte*)input->localpixels(),
+                                          input->spec().image_bytes())));
     }
     OIIO_DASSERT(src.get());
 
@@ -1325,9 +1329,8 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
             newspec.full_width  = newspec.width;
             newspec.full_height = newspec.height;
             newspec.full_depth  = newspec.depth;
-            std::string name    = std::string(src->name()) + ".constant_color";
-            src->reset(name, newspec);
-            ImageBufAlgo::fill(*src, &constantColor[0]);
+            src->reset(newspec);
+            ImageBufAlgo::fill(*src, constantColor);
             if (verbose) {
                 outstream << "  Constant color image detected. ";
                 outstream << "Creating " << newspec.width << "x"
@@ -1346,8 +1349,9 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
             outstream
                 << "  Alpha==1 image detected. Dropping the alpha channel.\n";
         std::shared_ptr<ImageBuf> newsrc(new ImageBuf(src->spec()));
-        ImageBufAlgo::channels(*newsrc, *src, src->nchannels() - 1, NULL, NULL,
-                               NULL, true);
+        ImageBufAlgo::channels(*newsrc, *src, src->nchannels() - 1,
+                               cspan<int>(), cspan<float>(),
+                               cspan<std::string>(), true);
         std::swap(src, newsrc);  // N.B. the old src will delete
     }
 
@@ -1367,7 +1371,8 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
                 outstream,
                 "  Monochrome image detected. Converting to single channel texture.\n");
         std::shared_ptr<ImageBuf> newsrc(new ImageBuf(src->spec()));
-        ImageBufAlgo::channels(*newsrc, *src, 1, NULL, NULL, NULL, true);
+        ImageBufAlgo::channels(*newsrc, *src, 1, cspan<int>(), cspan<float>(),
+                               cspan<std::string>(), true);
         newsrc->specmod().default_channel_names();
         std::swap(src, newsrc);
     }
@@ -1379,8 +1384,8 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
             outstream << "  Overriding number of channels to " << nchannels
                       << std::endl;
         std::shared_ptr<ImageBuf> newsrc(new ImageBuf(src->spec()));
-        ImageBufAlgo::channels(*newsrc, *src, nchannels, NULL, NULL, NULL,
-                               true);
+        ImageBufAlgo::channels(*newsrc, *src, nchannels, cspan<int>(),
+                               cspan<float>(), cspan<std::string>(), true);
         std::swap(src, newsrc);
     }
 
@@ -1623,14 +1628,14 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
         }
 
         ColorConfig colorconfig(colorconfigname);
-        if (colorconfig.error()) {
+        if (colorconfig.has_error()) {
             errorfmt("Error Creating ColorConfig: {}", colorconfig.geterror());
             return false;
         }
 
         ColorProcessorHandle processor
             = colorconfig.createColorProcessor(incolorspace, outcolorspace);
-        if (!processor || colorconfig.error()) {
+        if (!processor || colorconfig.has_error()) {
             errorfmt("Error Creating Color Processor: {}",
                      colorconfig.geterror());
             return false;
@@ -1649,9 +1654,8 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
         if (isConstantColor) {
             if (constantColor.size() < 3)
                 constantColor.resize(3, constantColor[0]);
-            if (!ImageBufAlgo::colorconvert(
-                    &constantColor[0], static_cast<int>(constantColor.size()),
-                    processor.get(), unpremult)) {
+            if (!ImageBufAlgo::colorconvert(constantColor, processor.get(),
+                                            unpremult)) {
                 errorfmt("Error applying color conversion to constant color.");
                 return false;
             }
@@ -1660,10 +1664,8 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
         if (compute_average_color) {
             if (pixel_stats.avg.size() < 3)
                 pixel_stats.avg.resize(3, pixel_stats.avg[0]);
-            if (!ImageBufAlgo::colorconvert(&pixel_stats.avg[0],
-                                            static_cast<int>(
-                                                pixel_stats.avg.size()),
-                                            processor.get(), unpremult)) {
+            if (!ImageBufAlgo::colorconvert(pixel_stats.avg, processor.get(),
+                                            unpremult)) {
                 errorfmt("Error applying color conversion to average color.");
                 return false;
             }
@@ -1756,7 +1758,8 @@ make_texture_impl(ImageBufAlgo::MakeTextureMode mode, const ImageBuf* input,
                 errorfmt("Could not make filter \"{}\"", resize_filter);
                 return false;
             }
-            ImageBufAlgo::resize(*toplevel, *src, filter);
+            ImageBufAlgo::resize(*toplevel, *src,
+                                 { make_pv("filterptr", filter) });
             Filter2D::destroy(filter);
         }
     }
