@@ -14,7 +14,8 @@
 #include <OpenImageIO/imageio.h>
 using namespace OIIO;
 
-void example1()
+void
+example1()
 {
     //
     // Example code fragment from the docs goes here.
@@ -32,7 +33,8 @@ void example1()
 
 
 
-int main(int /*argc*/, char** /*argv*/)
+int
+main(int /*argc*/, char** /*argv*/)
 {
     // Each example function needs to get called here, or it won't execute
     // as part of the test.
